#
# spec file for package perl-Email-Address
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Email-Address
Version:        1.912
Release:        lp150.2.3.1
%define cpan_name Email-Address
Summary:        RFC 2822 Address Parsing and Creation
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.96
%{perl_requires}

%description
This class implements a regex-based RFC 2822 parser that locates email
addresses in strings and returns a list of 'Email::Address' objects found.
Alternatively you may construct objects manually. The goal of this software
is to be correct, and very very fast.

Version 1.909 and earlier of this module had vulnerabilies (at
https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-7686) and (at
https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12558) which
allowed specially constructed email to cause a denial of service. The
reported vulnerabilities and some other pathalogical cases (meaning they
really shouldn't occur in normal email) have been addressed in version
1.910 and newer. If you're running version 1.909 or older, you should
update!

Alternatively, you could switch to *Email::Address::XS* which has a
backward compatible API.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Thu Jan  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.912
  see /usr/share/doc/packages/perl-Email-Address/Changes
  1.912     2018-12-31 13:46:22-05:00 America/New_York
  - include the doc updates from 1.911 changelog, oops!
* Sun Dec 23 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.911
  see /usr/share/doc/packages/perl-Email-Address/Changes
  1.911     2018-12-22 11:30:28-05:00 America/New_York
  - just like 1.910, but with doc updates and undeprecation by Jim Brandt
  1.910     2018-12-17 21:27:28-05:00 America/New_York (TRIAL RELEASE)
  - update parsing to mitigate pathological cases (thanks, sunnavy!)
- This update fixes CVE-2018-12558 (boo#1098368)
* Tue Mar  6 2018 coolo@suse.com
- updated to 1.909
  see /usr/share/doc/packages/perl-Email-Address/Changes
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.908
  see /usr/share/doc/packages/perl-Email-Address/Changes
  1.908     2015-09-19 22:53:38-04:00 America/New_York
  - default to 1 level of nested comments to avoid pathological behaviors
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.907
  see /usr/share/doc/packages/perl-Email-Address/Changes
  1.907     2015-02-03 17:48:10-05:00 America/New_York
  - restore 5.8.x compatibility
  1.906     2015-02-03 16:48:11-05:00 America/New_York
  - the test suite tests parses more directly, which eliminates a number
    of misleading (and possibly wrong) test cases
  - escaped characters in a quoted string are now properly unescaped
    for the ->phrase method, which means things should round trip better
    from their decomposed form
* Mon Sep 15 2014 coolo@suse.com
- updated to 1.905
  - additional change to avoid slowdown; this addresses CVE-2014-0477
    change provided by Bastian Blank <waldi@debian.org>
  1.904     2014-06-14 00:21:21-04:00 America/New_York (TRIAL RELEASE)
  - avoid being fooled by an addr-like string in the phrase
  - avoid a slowdown by avoiding backtracking into the phrase
  1.903     2014-04-17 21:02:14-04:00 America/New_York
  - correctly parenthesize false comment "0" (sigh)
  1.902     2014-04-17 10:45:11-04:00 America/New_York
  - when formatting an address where phrase is empty but comment is not,
    do not include "" for the phrase; just omit it
  - when formatting and address where comment lacks enclosing parens, add
    them
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.901
    further avoidance of stringifying to undef (thanks, this time, to
    David Golden)
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.900
    avoid trying to stringify undef, and so avoid a warning (thanks, Alex
    Vandiver)
* Tue Aug  6 2013 coolo@suse.com
- updated to 1.899
    repackaged, pointed at new bugtracker
    fallback overloads are enabled, so "cmp" will now compare with string
    overloads... which still might not be what you expect
    code has been futzed with to rely on some 5.6-isms, rather than
    trying to be 5.005 compatible
    a warning has been added: calling ->parse in scalar context gets
    undefined behavior
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.898
    remove dead link
    skip mailboxes, rather than aborting the whole parse, when
    encountering non-ASCII characters (thanks, Ruslan Zakirov!)
    improve the behavior of escaping in phrases (thanks, Ruslan Zakirov!)
    documentation improvements (thanks, Glenn Fowler!)
    allow non-ASCII *only in phrase*
    note that the use of the regex vars is not a great idea
    reject any non-ascii content in strings
* Sun Nov 13 2011 coolo@suse.com
- use original tar
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- update to 1.892
  o revert all behavior to 1.889
- 1.891     2010-08-30
  o rework domainless address feature to work on perl5.8 (Alex Vandiver)
- 1.890     2010-08-22
  o allow domainless addresses (if requested) (thanks, Alex Vandiver)
- created by cpanspec 1.78
  o fix deps
- noarch pkg
* Sat Dec 26 2009 lars@linux-schulserver.de
- added URL
* Tue Nov 24 2009 rschweikert@novell.com
- Upgrade to latest version 1.889
- Add build requirements (Test::Pod, Test::Pod::Coverage) to allow all
  tests to run
* Thu Sep 13 2007 James Oakley <jfunk@funktronics.ca> - 1.888-1
- Initial release
